# This puppet manifest is used to test backup and restore in an automated fashion
# This tests the backup and restores when manged by sunet::baas2 from puppet-sunet
# Jira-ref: SUNETOPS-1997

# @param node_type         The type of node, backupnode does the backups, restorenode does the restores
# @param backup_nodename   The name of the node that does the backups (only used by the restore node)
class net::baas2_restoretest(
  Enum['backupnode', 'restorenode'] $node_type,
  Optional[String] $backup_nodename = undef,
) {

  file { '/opt/baas2':
    ensure => directory,
    mode   => '0755',
    owner  => 'root',
    group  => 'root',
  }

  if $node_type == 'restorenode' {
    if $backup_nodename == undef {
      fail('Variable "backup_nodename" must be set for a restorenode')
    }

    package { 'expect': ensure => installed }

    file { '/opt/restore-target':
      ensure => directory,
      mode   => '0755',
      owner  => 'root',
      group  => 'root',
    }

    file { '/opt/baas2/run-successful-restore.expect':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/run-successful-restore.expect'),
    }

    file { '/opt/baas2/cancel-restore.expect':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/cancel-restore.expect'),
    }

    file { '/opt/baas2/run-failed-restore.expect':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/run-failed-restore.expect'),
    }

    file { '/opt/baas2/validate-backup-files':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/validate-backup-files'),
    }

    file { '/usr/local/sbin/baas2-check-restore-status':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/baas2-check-restore-status'),
    }

    sunet::scriptherder::cronjob { 'baas2-validate-backup-files':
      cmd         => "/opt/baas2/validate-backup-files ${backup_nodename}",
      minute      => '5',
      hour        => '8',
      ok_criteria => ['exit_status=0', 'max_age=48h'],
    }

  }

  if $node_type == 'backupnode' {
    file { '/opt/backup-test':
      ensure => directory,
      mode   => '0755',
      owner  => 'root',
      group  => 'root',
    }

    file { '/opt/baas2/gen-backup-files':
      ensure  => 'file',
      mode    => '0755',
      owner   => 'root',
      content => file('net/baas2_restoretest/gen-backup-files'),
    }

    sunet::scriptherder::cronjob { 'baas2-gen-backup-files':
      cmd         => '/opt/baas2/gen-backup-files',
      minute      => '25',
      hour        => '14',
      ok_criteria => ['exit_status=0', 'max_age=48h'],
    }
  }
}
